exceptiontools.ContextContainmentError
======================================

.. abjad-lineage:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError

.. autoclass:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ContextContainmentError.ContextContainmentError.__unicode__
   :noindex:
